"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DetailListScene:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DetailListSceneEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DetailListScene.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REPLY: _DetailListScene.ValueType  # 0
    """评论区展开"""
    MSG_FEED: _DetailListScene.ValueType  # 1
    """回复消息推送"""
    NOTIFY: _DetailListScene.ValueType  # 2
    """"""

class DetailListScene(_DetailListScene, metaclass=_DetailListSceneEnumTypeWrapper):
    """来源标识"""

REPLY: DetailListScene.ValueType  # 0
"""评论区展开"""
MSG_FEED: DetailListScene.ValueType  # 1
"""回复消息推送"""
NOTIFY: DetailListScene.ValueType  # 2
""""""
global___DetailListScene = DetailListScene

class _Mode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Mode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEFAULT: _Mode.ValueType  # 0
    """"""
    UNSPECIFIED: _Mode.ValueType  # 1
    """默认排序"""
    MAIN_LIST_TIME: _Mode.ValueType  # 2
    """按时间"""
    MAIN_LIST_HOT: _Mode.ValueType  # 3
    """按热度"""

class Mode(_Mode, metaclass=_ModeEnumTypeWrapper):
    """排序方式"""

DEFAULT: Mode.ValueType  # 0
""""""
UNSPECIFIED: Mode.ValueType  # 1
"""默认排序"""
MAIN_LIST_TIME: Mode.ValueType  # 2
"""按时间"""
MAIN_LIST_HOT: Mode.ValueType  # 3
"""按热度"""
global___Mode = Mode

class _SearchItemType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SearchItemTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SearchItemType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEFAULT_ITEM_TYPE: _SearchItemType.ValueType  # 0
    """"""
    GOODS: _SearchItemType.ValueType  # 1
    """"""
    VIDEO: _SearchItemType.ValueType  # 2
    """"""
    ARTICLE: _SearchItemType.ValueType  # 3
    """"""

class SearchItemType(_SearchItemType, metaclass=_SearchItemTypeEnumTypeWrapper):
    """"""

DEFAULT_ITEM_TYPE: SearchItemType.ValueType  # 0
""""""
GOODS: SearchItemType.ValueType  # 1
""""""
VIDEO: SearchItemType.ValueType  # 2
""""""
ARTICLE: SearchItemType.ValueType  # 3
""""""
global___SearchItemType = SearchItemType

class _SearchItemVideoSubType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SearchItemVideoSubTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SearchItemVideoSubType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UGC: _SearchItemVideoSubType.ValueType  # 0
    """"""
    PGC: _SearchItemVideoSubType.ValueType  # 1
    """"""

class SearchItemVideoSubType(_SearchItemVideoSubType, metaclass=_SearchItemVideoSubTypeEnumTypeWrapper):
    """"""

UGC: SearchItemVideoSubType.ValueType  # 0
""""""
PGC: SearchItemVideoSubType.ValueType  # 1
""""""
global___SearchItemVideoSubType = SearchItemVideoSubType

class _UserCallbackAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UserCallbackActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserCallbackAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Dismiss: _UserCallbackAction.ValueType  # 0
    """"""

class UserCallbackAction(_UserCallbackAction, metaclass=_UserCallbackActionEnumTypeWrapper):
    """"""

Dismiss: UserCallbackAction.ValueType  # 0
""""""
global___UserCallbackAction = UserCallbackAction

class _UserCallbackScene:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UserCallbackSceneEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserCallbackScene.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Insert: _UserCallbackScene.ValueType  # 0
    """"""

class UserCallbackScene(_UserCallbackScene, metaclass=_UserCallbackSceneEnumTypeWrapper):
    """"""

Insert: UserCallbackScene.ValueType  # 0
""""""
global___UserCallbackScene = UserCallbackScene

@typing_extensions.final
class Activity(google.protobuf.message.Message):
    """活动"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_STATE_FIELD_NUMBER: builtins.int
    ACTIVITY_PLACEHOLDER_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """活动id"""
    activity_state: builtins.int
    """活动状态
    -1:待审 1:上线
    """
    activity_placeholder: builtins.str
    """参与活动的输入框文案"""
    def __init__(
        self,
        *,
        activity_id: builtins.int = ...,
        activity_state: builtins.int = ...,
        activity_placeholder: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id", b"activity_id", "activity_placeholder", b"activity_placeholder", "activity_state", b"activity_state"]) -> None: ...

global___Activity = Activity

@typing_extensions.final
class ArticleSearchItem(google.protobuf.message.Message):
    """文章项目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    UP_NICKNAME_FIELD_NUMBER: builtins.int
    COVERS_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    up_nickname: builtins.str
    """UP主昵称"""
    @property
    def covers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """封面"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        up_nickname: builtins.str = ...,
        covers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["covers", b"covers", "title", b"title", "up_nickname", b"up_nickname"]) -> None: ...

global___ArticleSearchItem = ArticleSearchItem

@typing_extensions.final
class AtGroup(google.protobuf.message.Message):
    """评论at用户搜索组"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_TYPE_FIELD_NUMBER: builtins.int
    GROUP_NAME_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    group_type: builtins.int
    """组类型"""
    group_name: builtins.str
    """组标题"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AtItem]:
        """评论at用户搜索列表"""
    def __init__(
        self,
        *,
        group_type: builtins.int = ...,
        group_name: builtins.str = ...,
        items: collections.abc.Iterable[global___AtItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_name", b"group_name", "group_type", b"group_type", "items", b"items"]) -> None: ...

global___AtGroup = AtGroup

@typing_extensions.final
class AtItem(google.protobuf.message.Message):
    """评论at用户搜索条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_TYPE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""
    name: builtins.str
    """用户名"""
    face: builtins.str
    """用户头像url"""
    fans: builtins.int
    """用户是否关注"""
    official_verify_type: builtins.int
    """用户认证类型"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
        fans: builtins.int = ...,
        official_verify_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "fans", b"fans", "mid", b"mid", "name", b"name", "official_verify_type", b"official_verify_type"]) -> None: ...

global___AtItem = AtItem

@typing_extensions.final
class AtSearchReply(google.protobuf.message.Message):
    """评论at用户搜索-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPS_FIELD_NUMBER: builtins.int
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AtGroup]:
        """评论at用户搜索组"""
    def __init__(
        self,
        *,
        groups: collections.abc.Iterable[global___AtGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["groups", b"groups"]) -> None: ...

global___AtSearchReply = AtSearchReply

@typing_extensions.final
class AtSearchReq(google.protobuf.message.Message):
    """评论at用户搜索-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    keyword: builtins.str
    """关键字"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        keyword: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["keyword", b"keyword", "mid", b"mid"]) -> None: ...

global___AtSearchReq = AtSearchReq

@typing_extensions.final
class CM(google.protobuf.message.Message):
    """广告"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_CONTENT_FIELD_NUMBER: builtins.int
    @property
    def source_content(self) -> google.protobuf.any_pb2.Any:
        """广告数据(需要解包)"""
    def __init__(
        self,
        *,
        source_content: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_content", b"source_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_content", b"source_content"]) -> None: ...

global___CM = CM

@typing_extensions.final
class Content(google.protobuf.message.Message):
    """评论主体信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MenberEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Member: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Member | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class EmoteEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Emote: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Emote | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TopicEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Topic: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Topic | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class UrlEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Url: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Url | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class AtNameToMidEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    MESSAGE_FIELD_NUMBER: builtins.int
    MENBER_FIELD_NUMBER: builtins.int
    EMOTE_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    VOTE_FIELD_NUMBER: builtins.int
    AT_NAME_TO_MID_FIELD_NUMBER: builtins.int
    RICH_TEXT_FIELD_NUMBER: builtins.int
    PICTURES_FIELD_NUMBER: builtins.int
    message: builtins.str
    """评论文本"""
    @property
    def menber(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Member]:
        """需要渲染的用户转义"""
    @property
    def emote(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Emote]:
        """需要渲染的表情转义"""
    @property
    def topic(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Topic]:
        """需要高亮的话题转义"""
    @property
    def url(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Url]:
        """需要高亮的超链转义"""
    @property
    def vote(self) -> global___Vote:
        """投票信息"""
    @property
    def at_name_to_mid(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]:
        """at到的用户mid列表"""
    @property
    def rich_text(self) -> global___RichText:
        """富文本"""
    @property
    def pictures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Picture]:
        """评论图片"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        menber: collections.abc.Mapping[builtins.str, global___Member] | None = ...,
        emote: collections.abc.Mapping[builtins.str, global___Emote] | None = ...,
        topic: collections.abc.Mapping[builtins.str, global___Topic] | None = ...,
        url: collections.abc.Mapping[builtins.str, global___Url] | None = ...,
        vote: global___Vote | None = ...,
        at_name_to_mid: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
        rich_text: global___RichText | None = ...,
        pictures: collections.abc.Iterable[global___Picture] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rich_text", b"rich_text", "vote", b"vote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["at_name_to_mid", b"at_name_to_mid", "emote", b"emote", "menber", b"menber", "message", b"message", "pictures", b"pictures", "rich_text", b"rich_text", "topic", b"topic", "url", b"url", "vote", b"vote"]) -> None: ...

global___Content = Content

@typing_extensions.final
class Picture(google.protobuf.message.Message):
    """图片信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMG_SRC_FIELD_NUMBER: builtins.int
    IMG_WIDTH_FIELD_NUMBER: builtins.int
    IMG_HEIGHT_FIELD_NUMBER: builtins.int
    IMG_SIZE_FIELD_NUMBER: builtins.int
    img_src: builtins.str
    """图片URL"""
    img_width: builtins.float
    """图片宽度"""
    img_height: builtins.float
    """图片高度"""
    img_size: builtins.float
    """图片大小，单位KB"""
    def __init__(
        self,
        *,
        img_src: builtins.str = ...,
        img_width: builtins.float = ...,
        img_height: builtins.float = ...,
        img_size: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["img_height", b"img_height", "img_size", b"img_size", "img_src", b"img_src", "img_width", b"img_width"]) -> None: ...

global___Picture = Picture

@typing_extensions.final
class CursorReply(google.protobuf.message.Message):
    """页面游标回复"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEXT_FIELD_NUMBER: builtins.int
    PREV_FIELD_NUMBER: builtins.int
    ISBEGIN_FIELD_NUMBER: builtins.int
    ISEND_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    MODE_TEXT_FIELD_NUMBER: builtins.int
    next: builtins.int
    """下页数据"""
    prev: builtins.int
    """上页数据"""
    isBegin: builtins.bool
    """是否到顶"""
    isEnd: builtins.bool
    """是否到底"""
    mode: global___Mode.ValueType
    """排序方式
    2:时间 3:热度
    """
    mode_text: builtins.str
    """当前排序mode在切换按钮上的展示文案"""
    def __init__(
        self,
        *,
        next: builtins.int = ...,
        prev: builtins.int = ...,
        isBegin: builtins.bool = ...,
        isEnd: builtins.bool = ...,
        mode: global___Mode.ValueType = ...,
        mode_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["isBegin", b"isBegin", "isEnd", b"isEnd", "mode", b"mode", "mode_text", b"mode_text", "next", b"next", "prev", b"prev"]) -> None: ...

global___CursorReply = CursorReply

@typing_extensions.final
class CursorReq(google.protobuf.message.Message):
    """页面游标请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEXT_FIELD_NUMBER: builtins.int
    PREV_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    next: builtins.int
    """下页数据"""
    prev: builtins.int
    """上页数据"""
    mode: global___Mode.ValueType
    """排序方式"""
    def __init__(
        self,
        *,
        next: builtins.int = ...,
        prev: builtins.int = ...,
        mode: global___Mode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mode", b"mode", "next", b"next", "prev", b"prev"]) -> None: ...

global___CursorReq = CursorReq

@typing_extensions.final
class DetailListReply(google.protobuf.message.Message):
    """二级评论明细-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURSOR_FIELD_NUMBER: builtins.int
    SUBJECT_CONTROL_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int
    ACTIVITY_FIELD_NUMBER: builtins.int
    LIKES_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___CursorReply:
        """页面游标"""
    @property
    def subject_control(self) -> global___SubjectControl:
        """评论区显示控制字段"""
    @property
    def root(self) -> global___ReplyInfo:
        """根评论信息(带二级评论)"""
    @property
    def activity(self) -> global___Activity:
        """评论区的活动"""
    @property
    def likes(self) -> global___LikeInfo:
        """"""
    def __init__(
        self,
        *,
        cursor: global___CursorReply | None = ...,
        subject_control: global___SubjectControl | None = ...,
        root: global___ReplyInfo | None = ...,
        activity: global___Activity | None = ...,
        likes: global___LikeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity", b"activity", "cursor", b"cursor", "likes", b"likes", "root", b"root", "subject_control", b"subject_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity", b"activity", "cursor", b"cursor", "likes", b"likes", "root", b"root", "subject_control", b"subject_control"]) -> None: ...

global___DetailListReply = DetailListReply

@typing_extensions.final
class DetailListReq(google.protobuf.message.Message):
    """二级评论明细-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int
    RPID_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """目标评论区id"""
    type: builtins.int
    """目标评论区业务type"""
    root: builtins.int
    """根评论rpid"""
    rpid: builtins.int
    """目标评论rpid"""
    @property
    def cursor(self) -> global___CursorReq:
        """页面游标"""
    scene: global___DetailListScene.ValueType
    """来源标识"""
    def __init__(
        self,
        *,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        root: builtins.int = ...,
        rpid: builtins.int = ...,
        cursor: global___CursorReq | None = ...,
        scene: global___DetailListScene.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor", b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor", b"cursor", "oid", b"oid", "root", b"root", "rpid", b"rpid", "scene", b"scene", "type", b"type"]) -> None: ...

global___DetailListReq = DetailListReq

@typing_extensions.final
class DialogListReply(google.protobuf.message.Message):
    """对话评论树-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURSOR_FIELD_NUMBER: builtins.int
    SUBJECT_CONTROL_FIELD_NUMBER: builtins.int
    REPLIES_FIELD_NUMBER: builtins.int
    ACTIVITY_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___CursorReply:
        """页面游标"""
    @property
    def subject_control(self) -> global___SubjectControl:
        """评论区显示控制字段"""
    @property
    def replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyInfo]:
        """子评论列表"""
    @property
    def activity(self) -> global___Activity:
        """评论区的活动"""
    def __init__(
        self,
        *,
        cursor: global___CursorReply | None = ...,
        subject_control: global___SubjectControl | None = ...,
        replies: collections.abc.Iterable[global___ReplyInfo] | None = ...,
        activity: global___Activity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity", b"activity", "cursor", b"cursor", "subject_control", b"subject_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity", b"activity", "cursor", b"cursor", "replies", b"replies", "subject_control", b"subject_control"]) -> None: ...

global___DialogListReply = DialogListReply

@typing_extensions.final
class DialogListReq(google.protobuf.message.Message):
    """对话评论树-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int
    RPID_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """目标评论区id"""
    type: builtins.int
    """目标评论区业务type"""
    root: builtins.int
    """根评论rpid"""
    rpid: builtins.int
    """对话评论rpid"""
    @property
    def cursor(self) -> global___CursorReq:
        """页面游标"""
    def __init__(
        self,
        *,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        root: builtins.int = ...,
        rpid: builtins.int = ...,
        cursor: global___CursorReq | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor", b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor", b"cursor", "oid", b"oid", "root", b"root", "rpid", b"rpid", "type", b"type"]) -> None: ...

global___DialogListReq = DialogListReq

@typing_extensions.final
class Effects(google.protobuf.message.Message):
    """特效"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRELOADING_FIELD_NUMBER: builtins.int
    preloading: builtins.str
    """"""
    def __init__(
        self,
        *,
        preloading: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["preloading", b"preloading"]) -> None: ...

global___Effects = Effects

@typing_extensions.final
class Emote(google.protobuf.message.Message):
    """表情项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    JUMP_TITLE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PACKAGE_ID_FIELD_NUMBER: builtins.int
    GIF_URL_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    size: builtins.int
    """表情大小
    1:小 2:大
    """
    url: builtins.str
    """表情url"""
    jump_url: builtins.str
    """"""
    jump_title: builtins.str
    """"""
    id: builtins.int
    """"""
    package_id: builtins.int
    """"""
    gif_url: builtins.str
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        size: builtins.int = ...,
        url: builtins.str = ...,
        jump_url: builtins.str = ...,
        jump_title: builtins.str = ...,
        id: builtins.int = ...,
        package_id: builtins.int = ...,
        gif_url: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gif_url", b"gif_url", "id", b"id", "jump_title", b"jump_title", "jump_url", b"jump_url", "package_id", b"package_id", "size", b"size", "text", b"text", "url", b"url"]) -> None: ...

global___Emote = Emote

@typing_extensions.final
class GoodsSearchItem(google.protobuf.message.Message):
    """商品项目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    INCOME_FIELD_NUMBER: builtins.int
    IMG_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    id: builtins.int
    """商品id"""
    name: builtins.str
    """商品名"""
    price: builtins.str
    """价钱"""
    income: builtins.str
    """收入"""
    img: builtins.str
    """图片"""
    label: builtins.str
    """标签"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        price: builtins.str = ...,
        income: builtins.str = ...,
        img: builtins.str = ...,
        label: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "img", b"img", "income", b"income", "label", b"label", "name", b"name", "price", b"price"]) -> None: ...

global___GoodsSearchItem = GoodsSearchItem

@typing_extensions.final
class LikeInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Item(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MEMBER_FIELD_NUMBER: builtins.int
        @property
        def member(self) -> global___Member:
            """"""
        def __init__(
            self,
            *,
            member: global___Member | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["member", b"member"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["member", b"member"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LikeInfo.Item]:
        """"""
    title: builtins.str
    """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___LikeInfo.Item] | None = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "title", b"title"]) -> None: ...

global___LikeInfo = LikeInfo

@typing_extensions.final
class Lottery(google.protobuf.message.Message):
    """抽奖"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOTTERY_ID_FIELD_NUMBER: builtins.int
    LOTTERY_STATUS_FIELD_NUMBER: builtins.int
    LOTTERY_MID_FIELD_NUMBER: builtins.int
    LOTTERY_TIME_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    REPLY_CONTROL_FIELD_NUMBER: builtins.int
    lottery_id: builtins.int
    """抽奖id"""
    lottery_status: builtins.int
    """抽奖状态
    0:未开奖 1:开奖中 2:已开奖
    """
    lottery_mid: builtins.int
    """抽奖人mid"""
    lottery_time: builtins.int
    """开奖时间"""
    oid: builtins.int
    """"""
    type: builtins.int
    """"""
    ctime: builtins.int
    """发送时间"""
    @property
    def content(self) -> global___Content:
        """抽奖评论正文"""
    @property
    def member(self) -> global___Member:
        """用户信息"""
    @property
    def reply_control(self) -> global___ReplyControl:
        """评论条目控制字段"""
    def __init__(
        self,
        *,
        lottery_id: builtins.int = ...,
        lottery_status: builtins.int = ...,
        lottery_mid: builtins.int = ...,
        lottery_time: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        ctime: builtins.int = ...,
        content: global___Content | None = ...,
        member: global___Member | None = ...,
        reply_control: global___ReplyControl | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "member", b"member", "reply_control", b"reply_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "ctime", b"ctime", "lottery_id", b"lottery_id", "lottery_mid", b"lottery_mid", "lottery_status", b"lottery_status", "lottery_time", b"lottery_time", "member", b"member", "oid", b"oid", "reply_control", b"reply_control", "type", b"type"]) -> None: ...

global___Lottery = Lottery

@typing_extensions.final
class MainListReply(google.protobuf.message.Message):
    """主评论列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CallbacksEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CURSOR_FIELD_NUMBER: builtins.int
    REPLIES_FIELD_NUMBER: builtins.int
    SUBJECT_CONTROL_FIELD_NUMBER: builtins.int
    UP_TOP_FIELD_NUMBER: builtins.int
    ADMIN_TOP_FIELD_NUMBER: builtins.int
    VOTE_TOP_FIELD_NUMBER: builtins.int
    NOTICE_FIELD_NUMBER: builtins.int
    LOTTERY_FIELD_NUMBER: builtins.int
    ACTIVITY_FIELD_NUMBER: builtins.int
    UP_SELECTION_FIELD_NUMBER: builtins.int
    CM_FIELD_NUMBER: builtins.int
    EFFECTS_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    TOP_REPLIES_FIELD_NUMBER: builtins.int
    QOE_FIELD_NUMBER: builtins.int
    CALLBACKS_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___CursorReply:
        """页面游标"""
    @property
    def replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyInfo]:
        """评论列表"""
    @property
    def subject_control(self) -> global___SubjectControl:
        """评论区显示控制字段"""
    @property
    def up_top(self) -> global___ReplyInfo:
        """UP置顶评论"""
    @property
    def admin_top(self) -> global___ReplyInfo:
        """管理员置顶评论"""
    @property
    def vote_top(self) -> global___ReplyInfo:
        """投票置顶评论"""
    @property
    def notice(self) -> global___Notice:
        """评论区提示"""
    @property
    def lottery(self) -> global___Lottery:
        """抽奖评论"""
    @property
    def activity(self) -> global___Activity:
        """活动"""
    @property
    def up_selection(self) -> global___UpSelection:
        """精选评论区筛选后台信息"""
    @property
    def cm(self) -> global___CM:
        """广告"""
    @property
    def effects(self) -> global___Effects:
        """特效"""
    @property
    def operation(self) -> global___Operation:
        """"""
    @property
    def top_replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyInfo]:
        """"""
    @property
    def qoe(self) -> global___QoeInfo:
        """"""
    @property
    def callbacks(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]:
        """"""
    def __init__(
        self,
        *,
        cursor: global___CursorReply | None = ...,
        replies: collections.abc.Iterable[global___ReplyInfo] | None = ...,
        subject_control: global___SubjectControl | None = ...,
        up_top: global___ReplyInfo | None = ...,
        admin_top: global___ReplyInfo | None = ...,
        vote_top: global___ReplyInfo | None = ...,
        notice: global___Notice | None = ...,
        lottery: global___Lottery | None = ...,
        activity: global___Activity | None = ...,
        up_selection: global___UpSelection | None = ...,
        cm: global___CM | None = ...,
        effects: global___Effects | None = ...,
        operation: global___Operation | None = ...,
        top_replies: collections.abc.Iterable[global___ReplyInfo] | None = ...,
        qoe: global___QoeInfo | None = ...,
        callbacks: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity", b"activity", "admin_top", b"admin_top", "cm", b"cm", "cursor", b"cursor", "effects", b"effects", "lottery", b"lottery", "notice", b"notice", "operation", b"operation", "qoe", b"qoe", "subject_control", b"subject_control", "up_selection", b"up_selection", "up_top", b"up_top", "vote_top", b"vote_top"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity", b"activity", "admin_top", b"admin_top", "callbacks", b"callbacks", "cm", b"cm", "cursor", b"cursor", "effects", b"effects", "lottery", b"lottery", "notice", b"notice", "operation", b"operation", "qoe", b"qoe", "replies", b"replies", "subject_control", b"subject_control", "top_replies", b"top_replies", "up_selection", b"up_selection", "up_top", b"up_top", "vote_top", b"vote_top"]) -> None: ...

global___MainListReply = MainListReply

@typing_extensions.final
class MainListReq(google.protobuf.message.Message):
    """主评论列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    AD_EXTRA_FIELD_NUMBER: builtins.int
    RPID_FIELD_NUMBER: builtins.int
    SEEK_RPID_FIELD_NUMBER: builtins.int
    FILTER_TAG_NAME_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """目标评论区id"""
    type: builtins.int
    """目标评论区业务type"""
    @property
    def cursor(self) -> global___CursorReq:
        """页面游标"""
    extra: builtins.str
    """扩展数据json"""
    ad_extra: builtins.str
    """广告扩展"""
    rpid: builtins.int
    """目标评论rpid"""
    seek_rpid: builtins.int
    """"""
    filter_tag_name: builtins.str
    """评论区筛选类型 取值可为: ["全部" "粉丝评论" "笔记长评"]"""
    def __init__(
        self,
        *,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        cursor: global___CursorReq | None = ...,
        extra: builtins.str = ...,
        ad_extra: builtins.str = ...,
        rpid: builtins.int = ...,
        seek_rpid: builtins.int = ...,
        filter_tag_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor", b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_extra", b"ad_extra", "cursor", b"cursor", "extra", b"extra", "filter_tag_name", b"filter_tag_name", "oid", b"oid", "rpid", b"rpid", "seek_rpid", b"seek_rpid", "type", b"type"]) -> None: ...

global___MainListReq = MainListReq

@typing_extensions.final
class Member(google.protobuf.message.Message):
    """用户信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RegionType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RegionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Member._RegionType.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DEFAULT: Member._RegionType.ValueType  # 0
        """默认"""
        MAINLAND: Member._RegionType.ValueType  # 1
        """大陆地区"""
        GAT: Member._RegionType.ValueType  # 2
        """"""

    class RegionType(_RegionType, metaclass=_RegionTypeEnumTypeWrapper):
        """地区类型"""

    DEFAULT: Member.RegionType.ValueType  # 0
    """默认"""
    MAINLAND: Member.RegionType.ValueType  # 1
    """大陆地区"""
    GAT: Member.RegionType.ValueType  # 2
    """"""

    class _ShowStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ShowStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Member._ShowStatus.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SHOWDEFAULT: Member._ShowStatus.ValueType  # 0
        """默认"""
        ZOOMINMAINLAND: Member._ShowStatus.ValueType  # 1
        """"""
        RAW: Member._ShowStatus.ValueType  # 2
        """"""

    class ShowStatus(_ShowStatus, metaclass=_ShowStatusEnumTypeWrapper):
        """"""

    SHOWDEFAULT: Member.ShowStatus.ValueType  # 0
    """默认"""
    ZOOMINMAINLAND: Member.ShowStatus.ValueType  # 1
    """"""
    RAW: Member.ShowStatus.ValueType  # 2
    """"""

    @typing_extensions.final
    class Region(google.protobuf.message.Message):
        """NFT地区"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TYPE_FIELD_NUMBER: builtins.int
        ICON_FIELD_NUMBER: builtins.int
        SHOW_STATUS_FIELD_NUMBER: builtins.int
        type: global___Member.RegionType.ValueType
        """地区类型"""
        icon: builtins.str
        """角标url"""
        show_status: global___Member.ShowStatus.ValueType
        """"""
        def __init__(
            self,
            *,
            type: global___Member.RegionType.ValueType = ...,
            icon: builtins.str = ...,
            show_status: global___Member.ShowStatus.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "show_status", b"show_status", "type", b"type"]) -> None: ...

    @typing_extensions.final
    class NftInteraction(google.protobuf.message.Message):
        """NFT信息"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ITYPE_FIELD_NUMBER: builtins.int
        METADATA_URL_FIELD_NUMBER: builtins.int
        NFT_ID_FIELD_NUMBER: builtins.int
        REGION_FIELD_NUMBER: builtins.int
        itype: builtins.str
        """"""
        metadata_url: builtins.str
        """"""
        nft_id: builtins.str
        """"""
        @property
        def region(self) -> global___Member.Region:
            """NFT地区"""
        def __init__(
            self,
            *,
            itype: builtins.str = ...,
            metadata_url: builtins.str = ...,
            nft_id: builtins.str = ...,
            region: global___Member.Region | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["region", b"region"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["itype", b"itype", "metadata_url", b"metadata_url", "nft_id", b"nft_id", "region", b"region"]) -> None: ...

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SEX_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_TYPE_FIELD_NUMBER: builtins.int
    VIP_TYPE_FIELD_NUMBER: builtins.int
    VIP_STATUS_FIELD_NUMBER: builtins.int
    VIP_THEME_TYPE_FIELD_NUMBER: builtins.int
    VIP_LABEL_PATH_FIELD_NUMBER: builtins.int
    GARB_PENDANT_IMAGE_FIELD_NUMBER: builtins.int
    GARB_CARD_IMAGE_FIELD_NUMBER: builtins.int
    GARB_CARD_IMAGE_WITH_FOCUS_FIELD_NUMBER: builtins.int
    GARB_CARD_JUMP_URL_FIELD_NUMBER: builtins.int
    GARB_CARD_NUMBER_FIELD_NUMBER: builtins.int
    GARB_CARD_FAN_COLOR_FIELD_NUMBER: builtins.int
    GARB_CARD_IS_FAN_FIELD_NUMBER: builtins.int
    FANS_MEDAL_NAME_FIELD_NUMBER: builtins.int
    FANS_MEDAL_LEVEL_FIELD_NUMBER: builtins.int
    FANS_MEDAL_COLOR_FIELD_NUMBER: builtins.int
    VIP_NICKNAME_COLOR_FIELD_NUMBER: builtins.int
    VIP_AVATAR_SUBSCRIPT_FIELD_NUMBER: builtins.int
    VIP_LABEL_TEXT_FIELD_NUMBER: builtins.int
    VIP_LABEL_THEME_FIELD_NUMBER: builtins.int
    FANS_MEDAL_COLOR_END_FIELD_NUMBER: builtins.int
    FANS_MEDAL_COLOR_BORDER_FIELD_NUMBER: builtins.int
    FANS_MEDAL_COLOR_NAME_FIELD_NUMBER: builtins.int
    FANS_MEDAL_COLOR_LEVEL_FIELD_NUMBER: builtins.int
    FANS_GUARD_LEVEL_FIELD_NUMBER: builtins.int
    FACE_NFT_FIELD_NUMBER: builtins.int
    FACE_NFT_NEW_FIELD_NUMBER: builtins.int
    IS_SENIOR_MEMBER_FIELD_NUMBER: builtins.int
    NFT_INTERACTION_FIELD_NUMBER: builtins.int
    FANS_GUARD_ICON_FIELD_NUMBER: builtins.int
    FANS_HONOR_ICON_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""
    name: builtins.str
    """昵称"""
    sex: builtins.str
    """性别"""
    face: builtins.str
    """头像url"""
    level: builtins.int
    """等级"""
    official_verify_type: builtins.int
    """认证类型
    *********VIP相关*********
    """
    vip_type: builtins.int
    """会员类型
    0:不是大会员 1:月度会员 2:年度大会员
    """
    vip_status: builtins.int
    """会员状态"""
    vip_theme_type: builtins.int
    """会员样式"""
    vip_label_path: builtins.str
    """会员铭牌样式url
    *********装扮相关*********
    """
    garb_pendant_image: builtins.str
    """头像框url"""
    garb_card_image: builtins.str
    """装扮卡url"""
    garb_card_image_with_focus: builtins.str
    """有关注按钮时的装扮卡url"""
    garb_card_jump_url: builtins.str
    """专属装扮页面url"""
    garb_card_number: builtins.str
    """专属装扮id"""
    garb_card_fan_color: builtins.str
    """专属装扮id显示颜色"""
    garb_card_is_fan: builtins.bool
    """是否为专属装扮卡
    *********粉丝勋章相关*********
    """
    fans_medal_name: builtins.str
    """粉丝勋章名"""
    fans_medal_level: builtins.int
    """粉丝勋章等级"""
    fans_medal_color: builtins.int
    """粉丝勋章显示颜色"""
    vip_nickname_color: builtins.str
    """会员昵称颜色"""
    vip_avatar_subscript: builtins.int
    """会员角标
    0:无角标 1:粉色大会员角标 2:绿色小会员角标
    """
    vip_label_text: builtins.str
    """会员标签文"""
    vip_label_theme: builtins.str
    """会员标颜色"""
    fans_medal_color_end: builtins.int
    """粉丝勋章底色"""
    fans_medal_color_border: builtins.int
    """粉丝勋章边框颜色"""
    fans_medal_color_name: builtins.int
    """粉丝勋章名颜色"""
    fans_medal_color_level: builtins.int
    """粉丝勋章等级颜色"""
    fans_guard_level: builtins.int
    """"""
    face_nft: builtins.int
    """"""
    face_nft_new: builtins.int
    """是否NFT头像"""
    is_senior_member: builtins.int
    """是否为硬核会员"""
    @property
    def nft_interaction(self) -> global___Member.NftInteraction:
        """NFT信息"""
    fans_guard_icon: builtins.str
    """"""
    fans_honor_icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        sex: builtins.str = ...,
        face: builtins.str = ...,
        level: builtins.int = ...,
        official_verify_type: builtins.int = ...,
        vip_type: builtins.int = ...,
        vip_status: builtins.int = ...,
        vip_theme_type: builtins.int = ...,
        vip_label_path: builtins.str = ...,
        garb_pendant_image: builtins.str = ...,
        garb_card_image: builtins.str = ...,
        garb_card_image_with_focus: builtins.str = ...,
        garb_card_jump_url: builtins.str = ...,
        garb_card_number: builtins.str = ...,
        garb_card_fan_color: builtins.str = ...,
        garb_card_is_fan: builtins.bool = ...,
        fans_medal_name: builtins.str = ...,
        fans_medal_level: builtins.int = ...,
        fans_medal_color: builtins.int = ...,
        vip_nickname_color: builtins.str = ...,
        vip_avatar_subscript: builtins.int = ...,
        vip_label_text: builtins.str = ...,
        vip_label_theme: builtins.str = ...,
        fans_medal_color_end: builtins.int = ...,
        fans_medal_color_border: builtins.int = ...,
        fans_medal_color_name: builtins.int = ...,
        fans_medal_color_level: builtins.int = ...,
        fans_guard_level: builtins.int = ...,
        face_nft: builtins.int = ...,
        face_nft_new: builtins.int = ...,
        is_senior_member: builtins.int = ...,
        nft_interaction: global___Member.NftInteraction | None = ...,
        fans_guard_icon: builtins.str = ...,
        fans_honor_icon: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["nft_interaction", b"nft_interaction"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "face_nft", b"face_nft", "face_nft_new", b"face_nft_new", "fans_guard_icon", b"fans_guard_icon", "fans_guard_level", b"fans_guard_level", "fans_honor_icon", b"fans_honor_icon", "fans_medal_color", b"fans_medal_color", "fans_medal_color_border", b"fans_medal_color_border", "fans_medal_color_end", b"fans_medal_color_end", "fans_medal_color_level", b"fans_medal_color_level", "fans_medal_color_name", b"fans_medal_color_name", "fans_medal_level", b"fans_medal_level", "fans_medal_name", b"fans_medal_name", "garb_card_fan_color", b"garb_card_fan_color", "garb_card_image", b"garb_card_image", "garb_card_image_with_focus", b"garb_card_image_with_focus", "garb_card_is_fan", b"garb_card_is_fan", "garb_card_jump_url", b"garb_card_jump_url", "garb_card_number", b"garb_card_number", "garb_pendant_image", b"garb_pendant_image", "is_senior_member", b"is_senior_member", "level", b"level", "mid", b"mid", "name", b"name", "nft_interaction", b"nft_interaction", "official_verify_type", b"official_verify_type", "sex", b"sex", "vip_avatar_subscript", b"vip_avatar_subscript", "vip_label_path", b"vip_label_path", "vip_label_text", b"vip_label_text", "vip_label_theme", b"vip_label_theme", "vip_nickname_color", b"vip_nickname_color", "vip_status", b"vip_status", "vip_theme_type", b"vip_theme_type", "vip_type", b"vip_type"]) -> None: ...

global___Member = Member

@typing_extensions.final
class MemberV2(google.protobuf.message.Message):
    """用户信息V2"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RegionType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RegionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MemberV2._RegionType.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DEFAULT: MemberV2._RegionType.ValueType  # 0
        """默认"""
        MAINLAND: MemberV2._RegionType.ValueType  # 1
        """大陆地区"""
        GAT: MemberV2._RegionType.ValueType  # 2
        """"""

    class RegionType(_RegionType, metaclass=_RegionTypeEnumTypeWrapper):
        """地区类型"""

    DEFAULT: MemberV2.RegionType.ValueType  # 0
    """默认"""
    MAINLAND: MemberV2.RegionType.ValueType  # 1
    """大陆地区"""
    GAT: MemberV2.RegionType.ValueType  # 2
    """"""

    class _ShowStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ShowStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MemberV2._ShowStatus.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SHOWDEFAULT: MemberV2._ShowStatus.ValueType  # 0
        """"""
        ZOOMINMAINLAND: MemberV2._ShowStatus.ValueType  # 1
        """"""
        RAW: MemberV2._ShowStatus.ValueType  # 2
        """"""

    class ShowStatus(_ShowStatus, metaclass=_ShowStatusEnumTypeWrapper):
        """"""

    SHOWDEFAULT: MemberV2.ShowStatus.ValueType  # 0
    """"""
    ZOOMINMAINLAND: MemberV2.ShowStatus.ValueType  # 1
    """"""
    RAW: MemberV2.ShowStatus.ValueType  # 2
    """"""

    @typing_extensions.final
    class Basic(google.protobuf.message.Message):
        """基本信息"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MID_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        SEX_FIELD_NUMBER: builtins.int
        FACE_FIELD_NUMBER: builtins.int
        LEVEL_FIELD_NUMBER: builtins.int
        mid: builtins.int
        """用户mid"""
        name: builtins.str
        """昵称"""
        sex: builtins.str
        """性别"""
        face: builtins.str
        """头像url"""
        level: builtins.int
        """等级"""
        def __init__(
            self,
            *,
            mid: builtins.int = ...,
            name: builtins.str = ...,
            sex: builtins.str = ...,
            face: builtins.str = ...,
            level: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "level", b"level", "mid", b"mid", "name", b"name", "sex", b"sex"]) -> None: ...

    @typing_extensions.final
    class Official(google.protobuf.message.Message):
        """认证"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VERIFY_TYPE_FIELD_NUMBER: builtins.int
        verify_type: builtins.int
        """认证类型"""
        def __init__(
            self,
            *,
            verify_type: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["verify_type", b"verify_type"]) -> None: ...

    @typing_extensions.final
    class Vip(google.protobuf.message.Message):
        """大会员"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TYPE_FIELD_NUMBER: builtins.int
        STATUS_FIELD_NUMBER: builtins.int
        THEME_TYPE_FIELD_NUMBER: builtins.int
        LABEL_PATH_FIELD_NUMBER: builtins.int
        NICKNAME_COLOR_FIELD_NUMBER: builtins.int
        AVATAR_SUBSCRIPT_FIELD_NUMBER: builtins.int
        LABEL_TEXT_FIELD_NUMBER: builtins.int
        VIP_LABEL_THEME_FIELD_NUMBER: builtins.int
        type: builtins.int
        """会员类型
        0:不是大会员 1:月度会员 2:年度大会员
        """
        status: builtins.int
        """会员状态"""
        theme_type: builtins.int
        """会员样式"""
        label_path: builtins.str
        """会员铭牌样式url"""
        nickname_color: builtins.str
        """"""
        avatar_subscript: builtins.int
        """"""
        label_text: builtins.str
        """"""
        vip_label_theme: builtins.str
        """"""
        def __init__(
            self,
            *,
            type: builtins.int = ...,
            status: builtins.int = ...,
            theme_type: builtins.int = ...,
            label_path: builtins.str = ...,
            nickname_color: builtins.str = ...,
            avatar_subscript: builtins.int = ...,
            label_text: builtins.str = ...,
            vip_label_theme: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["avatar_subscript", b"avatar_subscript", "label_path", b"label_path", "label_text", b"label_text", "nickname_color", b"nickname_color", "status", b"status", "theme_type", b"theme_type", "type", b"type", "vip_label_theme", b"vip_label_theme"]) -> None: ...

    @typing_extensions.final
    class Garb(google.protobuf.message.Message):
        """装扮"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PENDANT_IMAGE_FIELD_NUMBER: builtins.int
        CARD_IMAGE_FIELD_NUMBER: builtins.int
        CARD_IMAGE_WITH_FOCUS_FIELD_NUMBER: builtins.int
        CARD_JUMP_URL_FIELD_NUMBER: builtins.int
        CARD_NUMBER_FIELD_NUMBER: builtins.int
        CARD_FAN_COLOR_FIELD_NUMBER: builtins.int
        CARD_IS_FAN_FIELD_NUMBER: builtins.int
        pendant_image: builtins.str
        """头像框url"""
        card_image: builtins.str
        """装扮卡url"""
        card_image_with_focus: builtins.str
        """有关注按钮时的装扮卡url"""
        card_jump_url: builtins.str
        """专属装扮页面url"""
        card_number: builtins.str
        """专属装扮id"""
        card_fan_color: builtins.str
        """专属装扮id显示颜色"""
        card_is_fan: builtins.bool
        """是否为专属装扮卡"""
        def __init__(
            self,
            *,
            pendant_image: builtins.str = ...,
            card_image: builtins.str = ...,
            card_image_with_focus: builtins.str = ...,
            card_jump_url: builtins.str = ...,
            card_number: builtins.str = ...,
            card_fan_color: builtins.str = ...,
            card_is_fan: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["card_fan_color", b"card_fan_color", "card_image", b"card_image", "card_image_with_focus", b"card_image_with_focus", "card_is_fan", b"card_is_fan", "card_jump_url", b"card_jump_url", "card_number", b"card_number", "pendant_image", b"pendant_image"]) -> None: ...

    @typing_extensions.final
    class Medal(google.protobuf.message.Message):
        """粉丝勋章"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        LEVEL_FIELD_NUMBER: builtins.int
        COLOR_START_FIELD_NUMBER: builtins.int
        COLOR_END_FIELD_NUMBER: builtins.int
        COLOR_BORDER_FIELD_NUMBER: builtins.int
        COLOR_NAME_FIELD_NUMBER: builtins.int
        COLOR_LEVEL_FIELD_NUMBER: builtins.int
        GUARD_LEVEL_FIELD_NUMBER: builtins.int
        FIRST_ICON_FIELD_NUMBER: builtins.int
        LEVEL_BG_COLOR_FIELD_NUMBER: builtins.int
        name: builtins.str
        """粉丝勋章名"""
        level: builtins.int
        """粉丝勋章等级"""
        color_start: builtins.int
        """粉丝勋章显示颜色"""
        color_end: builtins.int
        """粉丝勋章底色"""
        color_border: builtins.int
        """粉丝勋章边框颜色"""
        color_name: builtins.int
        """粉丝勋章名颜色"""
        color_level: builtins.int
        """粉丝勋章等级颜色"""
        guard_level: builtins.int
        """"""
        first_icon: builtins.str
        """"""
        level_bg_color: builtins.int
        """"""
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            level: builtins.int = ...,
            color_start: builtins.int = ...,
            color_end: builtins.int = ...,
            color_border: builtins.int = ...,
            color_name: builtins.int = ...,
            color_level: builtins.int = ...,
            guard_level: builtins.int = ...,
            first_icon: builtins.str = ...,
            level_bg_color: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["color_border", b"color_border", "color_end", b"color_end", "color_level", b"color_level", "color_name", b"color_name", "color_start", b"color_start", "first_icon", b"first_icon", "guard_level", b"guard_level", "level", b"level", "level_bg_color", b"level_bg_color", "name", b"name"]) -> None: ...

    @typing_extensions.final
    class Region(google.protobuf.message.Message):
        """NFT地区"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TYPE_FIELD_NUMBER: builtins.int
        ICON_FIELD_NUMBER: builtins.int
        SHOW_STATUS_FIELD_NUMBER: builtins.int
        type: global___MemberV2.RegionType.ValueType
        """地区类型"""
        icon: builtins.str
        """角标url"""
        show_status: global___MemberV2.ShowStatus.ValueType
        """"""
        def __init__(
            self,
            *,
            type: global___MemberV2.RegionType.ValueType = ...,
            icon: builtins.str = ...,
            show_status: global___MemberV2.ShowStatus.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "show_status", b"show_status", "type", b"type"]) -> None: ...

    @typing_extensions.final
    class Interaction(google.protobuf.message.Message):
        """NFT信息"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ITYPE_FIELD_NUMBER: builtins.int
        METADATA_URL_FIELD_NUMBER: builtins.int
        NFT_ID_FIELD_NUMBER: builtins.int
        REGION_FIELD_NUMBER: builtins.int
        itype: builtins.str
        """"""
        metadata_url: builtins.str
        """"""
        nft_id: builtins.str
        """"""
        @property
        def region(self) -> global___MemberV2.Region:
            """NFT地区"""
        def __init__(
            self,
            *,
            itype: builtins.str = ...,
            metadata_url: builtins.str = ...,
            nft_id: builtins.str = ...,
            region: global___MemberV2.Region | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["region", b"region"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["itype", b"itype", "metadata_url", b"metadata_url", "nft_id", b"nft_id", "region", b"region"]) -> None: ...

    @typing_extensions.final
    class Nft(google.protobuf.message.Message):
        """NFT"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FACE_FIELD_NUMBER: builtins.int
        INTERACTION_FIELD_NUMBER: builtins.int
        face: builtins.int
        """"""
        @property
        def interaction(self) -> global___MemberV2.Interaction:
            """"""
        def __init__(
            self,
            *,
            face: builtins.int = ...,
            interaction: global___MemberV2.Interaction | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["interaction", b"interaction"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "interaction", b"interaction"]) -> None: ...

    @typing_extensions.final
    class Senior(google.protobuf.message.Message):
        """硬核会员"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IS_SENIOR_MEMBER_FIELD_NUMBER: builtins.int
        is_senior_member: builtins.int
        """是否为硬核会员"""
        def __init__(
            self,
            *,
            is_senior_member: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["is_senior_member", b"is_senior_member"]) -> None: ...

    @typing_extensions.final
    class Contractor(google.protobuf.message.Message):
        """契约"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IS_CONTRACTOR_FIELD_NUMBER: builtins.int
        CONTRACT_DESC_FIELD_NUMBER: builtins.int
        is_contractor: builtins.bool
        """是否和up签订契约"""
        contract_desc: builtins.str
        """契约显示文案"""
        def __init__(
            self,
            *,
            is_contractor: builtins.bool = ...,
            contract_desc: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["contract_desc", b"contract_desc", "is_contractor", b"is_contractor"]) -> None: ...

    BASIC_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    GARB_FIELD_NUMBER: builtins.int
    MEDAL_FIELD_NUMBER: builtins.int
    NFT_FIELD_NUMBER: builtins.int
    SENIOR_FIELD_NUMBER: builtins.int
    CONTRACTOR_FIELD_NUMBER: builtins.int
    @property
    def basic(self) -> global___MemberV2.Basic:
        """基本信息"""
    @property
    def official(self) -> global___MemberV2.Official:
        """认证信息"""
    @property
    def vip(self) -> global___MemberV2.Vip:
        """大会员信息"""
    @property
    def garb(self) -> global___MemberV2.Garb:
        """装扮信息"""
    @property
    def medal(self) -> global___MemberV2.Medal:
        """粉丝勋章信息"""
    @property
    def nft(self) -> global___MemberV2.Nft:
        """NFT信息"""
    @property
    def senior(self) -> global___MemberV2.Senior:
        """硬核会员信息"""
    @property
    def contractor(self) -> global___MemberV2.Contractor:
        """契约信息"""
    def __init__(
        self,
        *,
        basic: global___MemberV2.Basic | None = ...,
        official: global___MemberV2.Official | None = ...,
        vip: global___MemberV2.Vip | None = ...,
        garb: global___MemberV2.Garb | None = ...,
        medal: global___MemberV2.Medal | None = ...,
        nft: global___MemberV2.Nft | None = ...,
        senior: global___MemberV2.Senior | None = ...,
        contractor: global___MemberV2.Contractor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["basic", b"basic", "contractor", b"contractor", "garb", b"garb", "medal", b"medal", "nft", b"nft", "official", b"official", "senior", b"senior", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["basic", b"basic", "contractor", b"contractor", "garb", b"garb", "medal", b"medal", "nft", b"nft", "official", b"official", "senior", b"senior", "vip", b"vip"]) -> None: ...

global___MemberV2 = MemberV2

@typing_extensions.final
class Notice(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    content: builtins.str
    """"""
    link: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        content: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "id", b"id", "link", b"link"]) -> None: ...

global___Notice = Notice

@typing_extensions.final
class Operation(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    REPORT_EXTRA_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    id: builtins.int
    """"""
    @property
    def title(self) -> global___OperationTitle:
        """"""
    @property
    def subtitle(self) -> global___OperationTitle:
        """"""
    link: builtins.str
    """"""
    report_extra: builtins.str
    """"""
    icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        id: builtins.int = ...,
        title: global___OperationTitle | None = ...,
        subtitle: global___OperationTitle | None = ...,
        link: builtins.str = ...,
        report_extra: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subtitle", b"subtitle", "title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "id", b"id", "link", b"link", "report_extra", b"report_extra", "subtitle", b"subtitle", "title", b"title", "type", b"type"]) -> None: ...

global___Operation = Operation

@typing_extensions.final
class OperationTitle(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    IS_HIGHLIGHT_FIELD_NUMBER: builtins.int
    content: builtins.str
    """"""
    is_highlight: builtins.bool
    """"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        is_highlight: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "is_highlight", b"is_highlight"]) -> None: ...

global___OperationTitle = OperationTitle

@typing_extensions.final
class PGCVideoSearchItem(google.protobuf.message.Message):
    """PGC视频项目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    category: builtins.str
    """类别"""
    cover: builtins.str
    """封面"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        category: builtins.str = ...,
        cover: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["category", b"category", "cover", b"cover", "title", b"title"]) -> None: ...

global___PGCVideoSearchItem = PGCVideoSearchItem

@typing_extensions.final
class PreviewListReply(google.protobuf.message.Message):
    """评论区预览-回复"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURSOR_FIELD_NUMBER: builtins.int
    REPLIES_FIELD_NUMBER: builtins.int
    SUBJECT_CONTROL_FIELD_NUMBER: builtins.int
    UPTOP_FIELD_NUMBER: builtins.int
    ADMIN_TOP_FIELD_NUMBER: builtins.int
    VOTE_TOP_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___CursorReply:
        """页面游标"""
    @property
    def replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyInfo]:
        """评论列表"""
    @property
    def subject_control(self) -> global___SubjectControl:
        """评论区显示控制字段"""
    @property
    def upTop(self) -> global___ReplyInfo:
        """UP置顶评论"""
    @property
    def admin_top(self) -> global___ReplyInfo:
        """管理员置顶评论"""
    @property
    def vote_top(self) -> global___ReplyInfo:
        """投票置顶评论"""
    def __init__(
        self,
        *,
        cursor: global___CursorReply | None = ...,
        replies: collections.abc.Iterable[global___ReplyInfo] | None = ...,
        subject_control: global___SubjectControl | None = ...,
        upTop: global___ReplyInfo | None = ...,
        admin_top: global___ReplyInfo | None = ...,
        vote_top: global___ReplyInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["admin_top", b"admin_top", "cursor", b"cursor", "subject_control", b"subject_control", "upTop", b"upTop", "vote_top", b"vote_top"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_top", b"admin_top", "cursor", b"cursor", "replies", b"replies", "subject_control", b"subject_control", "upTop", b"upTop", "vote_top", b"vote_top"]) -> None: ...

global___PreviewListReply = PreviewListReply

@typing_extensions.final
class PreviewListReq(google.protobuf.message.Message):
    """评论区预览-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """目标评论区id"""
    type: builtins.int
    """目标评论区业务type"""
    @property
    def cursor(self) -> global___CursorReq:
        """页面游标"""
    def __init__(
        self,
        *,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        cursor: global___CursorReq | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor", b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor", b"cursor", "oid", b"oid", "type", b"type"]) -> None: ...

global___PreviewListReq = PreviewListReq

@typing_extensions.final
class QoeInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    FEEDBACK_TITLE_FIELD_NUMBER: builtins.int
    SCORE_ITEMS_FIELD_NUMBER: builtins.int
    DISPLAY_RANK_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    type: builtins.int
    """"""
    style: builtins.int
    """"""
    title: builtins.str
    """"""
    feedback_title: builtins.str
    """"""
    @property
    def score_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QoeScoreItem]:
        """"""
    display_rank: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        type: builtins.int = ...,
        style: builtins.int = ...,
        title: builtins.str = ...,
        feedback_title: builtins.str = ...,
        score_items: collections.abc.Iterable[global___QoeScoreItem] | None = ...,
        display_rank: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_rank", b"display_rank", "feedback_title", b"feedback_title", "id", b"id", "score_items", b"score_items", "style", b"style", "title", b"title", "type", b"type"]) -> None: ...

global___QoeInfo = QoeInfo

@typing_extensions.final
class QoeScoreItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    url: builtins.str
    """"""
    score: builtins.float
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        url: builtins.str = ...,
        score: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["score", b"score", "title", b"title", "url", b"url"]) -> None: ...

global___QoeScoreItem = QoeScoreItem

@typing_extensions.final
class ReplyCardLabel(google.protobuf.message.Message):
    """评论条目标签信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_CONTENT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_DAY_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    LABEL_COLOR_DAY_FIELD_NUMBER: builtins.int
    LABEL_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    BACKGROUND_FIELD_NUMBER: builtins.int
    BACKGROUND_WIDTH_FIELD_NUMBER: builtins.int
    BACKGROUND_HEIGHT_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    EFFECT_FIELD_NUMBER: builtins.int
    EFFECT_START_TIME_FIELD_NUMBER: builtins.int
    text_content: builtins.str
    """标签文本"""
    text_color_day: builtins.str
    """文本颜色"""
    text_color_night: builtins.str
    """文本颜色夜间"""
    label_color_day: builtins.str
    """标签颜色"""
    label_color_night: builtins.str
    """标签颜色夜间"""
    image: builtins.str
    """"""
    type: builtins.int
    """标签类型 0:UP主觉得很赞 1:妙评"""
    background: builtins.str
    """背景url"""
    background_width: builtins.float
    """背景宽"""
    background_height: builtins.float
    """背景高"""
    jump_url: builtins.str
    """点击跳转url"""
    effect: builtins.int
    """"""
    effect_start_time: builtins.int
    """"""
    def __init__(
        self,
        *,
        text_content: builtins.str = ...,
        text_color_day: builtins.str = ...,
        text_color_night: builtins.str = ...,
        label_color_day: builtins.str = ...,
        label_color_night: builtins.str = ...,
        image: builtins.str = ...,
        type: builtins.int = ...,
        background: builtins.str = ...,
        background_width: builtins.float = ...,
        background_height: builtins.float = ...,
        jump_url: builtins.str = ...,
        effect: builtins.int = ...,
        effect_start_time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background", b"background", "background_height", b"background_height", "background_width", b"background_width", "effect", b"effect", "effect_start_time", b"effect_start_time", "image", b"image", "jump_url", b"jump_url", "label_color_day", b"label_color_day", "label_color_night", b"label_color_night", "text_color_day", b"text_color_day", "text_color_night", b"text_color_night", "text_content", b"text_content", "type", b"type"]) -> None: ...

global___ReplyCardLabel = ReplyCardLabel

@typing_extensions.final
class ReplyControl(google.protobuf.message.Message):
    """评论条目控制字段"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    UP_LIKE_FIELD_NUMBER: builtins.int
    UP_REPLY_FIELD_NUMBER: builtins.int
    SHOW_FOLLOW_BTN_FIELD_NUMBER: builtins.int
    IS_ASSIST_FIELD_NUMBER: builtins.int
    LABEL_TEXT_FIELD_NUMBER: builtins.int
    FOLLOWING_FIELD_NUMBER: builtins.int
    FOLLOWED_FIELD_NUMBER: builtins.int
    BLOCKED_FIELD_NUMBER: builtins.int
    HAS_FOLDED_REPLY_FIELD_NUMBER: builtins.int
    IS_FOLDED_REPLY_FIELD_NUMBER: builtins.int
    IS_UP_TOP_FIELD_NUMBER: builtins.int
    IS_ADMIN_TOP_FIELD_NUMBER: builtins.int
    IS_VOTE_TOP_FIELD_NUMBER: builtins.int
    MAX_LINE_FIELD_NUMBER: builtins.int
    INVISIBLE_FIELD_NUMBER: builtins.int
    IS_CONTRACTOR_FIELD_NUMBER: builtins.int
    IS_NOTE_FIELD_NUMBER: builtins.int
    CARD_LABELS_FIELD_NUMBER: builtins.int
    SUB_REPLY_ENTRY_TEXT_FIELD_NUMBER: builtins.int
    SUB_REPLY_TITLE_TEXT_FIELD_NUMBER: builtins.int
    CONTRACT_DESC_FIELD_NUMBER: builtins.int
    TIME_DESC_FIELD_NUMBER: builtins.int
    BIZ_SCENE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    action: builtins.int
    """操作行为标志
    0:无 1:已点赞 2:已点踩
    """
    up_like: builtins.bool
    """是否UP觉得很赞"""
    up_reply: builtins.bool
    """是否存在UP回复"""
    show_follow_btn: builtins.bool
    """是否显示关注按钮"""
    is_assist: builtins.bool
    """是否协管"""
    label_text: builtins.str
    """是否展示标签"""
    following: builtins.bool
    """是否关注"""
    followed: builtins.bool
    """是否粉丝"""
    blocked: builtins.bool
    """是否被自己拉黑"""
    has_folded_reply: builtins.bool
    """是否存在折叠的二级评论"""
    is_folded_reply: builtins.bool
    """是否折叠"""
    is_up_top: builtins.bool
    """是否UP置顶"""
    is_admin_top: builtins.bool
    """是否管理置顶"""
    is_vote_top: builtins.bool
    """是否置顶投票评论"""
    max_line: builtins.int
    """最大收起显示行数"""
    invisible: builtins.bool
    """该条评论可不可见"""
    is_contractor: builtins.bool
    """是否和up签订契约"""
    is_note: builtins.bool
    """是否是笔记评论"""
    @property
    def card_labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyCardLabel]:
        """评论条目标签列表"""
    sub_reply_entry_text: builtins.str
    """子评论数文案 "共x条回复" """
    sub_reply_title_text: builtins.str
    """子评论数文案 "相关回复共x条" """
    contract_desc: builtins.str
    """契约显示文案"""
    time_desc: builtins.str
    """发布时间文案 "x天前发布" """
    biz_scene: builtins.str
    """"""
    location: builtins.str
    """IP属地信息 "IP属地：xxx" """
    def __init__(
        self,
        *,
        action: builtins.int = ...,
        up_like: builtins.bool = ...,
        up_reply: builtins.bool = ...,
        show_follow_btn: builtins.bool = ...,
        is_assist: builtins.bool = ...,
        label_text: builtins.str = ...,
        following: builtins.bool = ...,
        followed: builtins.bool = ...,
        blocked: builtins.bool = ...,
        has_folded_reply: builtins.bool = ...,
        is_folded_reply: builtins.bool = ...,
        is_up_top: builtins.bool = ...,
        is_admin_top: builtins.bool = ...,
        is_vote_top: builtins.bool = ...,
        max_line: builtins.int = ...,
        invisible: builtins.bool = ...,
        is_contractor: builtins.bool = ...,
        is_note: builtins.bool = ...,
        card_labels: collections.abc.Iterable[global___ReplyCardLabel] | None = ...,
        sub_reply_entry_text: builtins.str = ...,
        sub_reply_title_text: builtins.str = ...,
        contract_desc: builtins.str = ...,
        time_desc: builtins.str = ...,
        biz_scene: builtins.str = ...,
        location: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "biz_scene", b"biz_scene", "blocked", b"blocked", "card_labels", b"card_labels", "contract_desc", b"contract_desc", "followed", b"followed", "following", b"following", "has_folded_reply", b"has_folded_reply", "invisible", b"invisible", "is_admin_top", b"is_admin_top", "is_assist", b"is_assist", "is_contractor", b"is_contractor", "is_folded_reply", b"is_folded_reply", "is_note", b"is_note", "is_up_top", b"is_up_top", "is_vote_top", b"is_vote_top", "label_text", b"label_text", "location", b"location", "max_line", b"max_line", "show_follow_btn", b"show_follow_btn", "sub_reply_entry_text", b"sub_reply_entry_text", "sub_reply_title_text", b"sub_reply_title_text", "time_desc", b"time_desc", "up_like", b"up_like", "up_reply", b"up_reply"]) -> None: ...

global___ReplyControl = ReplyControl

@typing_extensions.final
class ReplyExtra(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    EP_ID_FIELD_NUMBER: builtins.int
    IS_STORY_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    season_type: builtins.int
    """"""
    ep_id: builtins.int
    """"""
    is_story: builtins.bool
    """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        season_type: builtins.int = ...,
        ep_id: builtins.int = ...,
        is_story: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ep_id", b"ep_id", "is_story", b"is_story", "season_id", b"season_id", "season_type", b"season_type"]) -> None: ...

global___ReplyExtra = ReplyExtra

@typing_extensions.final
class ReplyInfo(google.protobuf.message.Message):
    """评论条目信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLIES_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    DIALOG_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    REPLY_CONTROL_FIELD_NUMBER: builtins.int
    MEMBER_V2_FIELD_NUMBER: builtins.int
    @property
    def replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyInfo]:
        """二级评论列表"""
    id: builtins.int
    """评论rpid"""
    oid: builtins.int
    """评论区对象id"""
    type: builtins.int
    """评论区类型"""
    mid: builtins.int
    """发布者UID"""
    root: builtins.int
    """根评论rpid"""
    parent: builtins.int
    """父评论rpid"""
    dialog: builtins.int
    """对话评论rpid"""
    like: builtins.int
    """点赞数"""
    ctime: builtins.int
    """发布时间"""
    count: builtins.int
    """回复数"""
    @property
    def content(self) -> global___Content:
        """评论主体信息"""
    @property
    def member(self) -> global___Member:
        """发布者信息"""
    @property
    def reply_control(self) -> global___ReplyControl:
        """评论控制字段"""
    @property
    def member_v2(self) -> global___MemberV2:
        """发布者信息V2"""
    def __init__(
        self,
        *,
        replies: collections.abc.Iterable[global___ReplyInfo] | None = ...,
        id: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        mid: builtins.int = ...,
        root: builtins.int = ...,
        parent: builtins.int = ...,
        dialog: builtins.int = ...,
        like: builtins.int = ...,
        ctime: builtins.int = ...,
        count: builtins.int = ...,
        content: global___Content | None = ...,
        member: global___Member | None = ...,
        reply_control: global___ReplyControl | None = ...,
        member_v2: global___MemberV2 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "member", b"member", "member_v2", b"member_v2", "reply_control", b"reply_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "count", b"count", "ctime", b"ctime", "dialog", b"dialog", "id", b"id", "like", b"like", "member", b"member", "member_v2", b"member_v2", "mid", b"mid", "oid", b"oid", "parent", b"parent", "replies", b"replies", "reply_control", b"reply_control", "root", b"root", "type", b"type"]) -> None: ...

global___ReplyInfo = ReplyInfo

@typing_extensions.final
class ReplyInfoReply(google.protobuf.message.Message):
    """查询单条评论-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLY_FIELD_NUMBER: builtins.int
    @property
    def reply(self) -> global___ReplyInfo:
        """评论条目信息"""
    def __init__(
        self,
        *,
        reply: global___ReplyInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["reply", b"reply"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["reply", b"reply"]) -> None: ...

global___ReplyInfoReply = ReplyInfoReply

@typing_extensions.final
class ReplyInfoReq(google.protobuf.message.Message):
    """查询单条评论-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RPID_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    rpid: builtins.int
    """评论rpid"""
    scene: builtins.int
    """"""
    def __init__(
        self,
        *,
        rpid: builtins.int = ...,
        scene: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rpid", b"rpid", "scene", b"scene"]) -> None: ...

global___ReplyInfoReq = ReplyInfoReq

@typing_extensions.final
class RichText(google.protobuf.message.Message):
    """富文本"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTE_FIELD_NUMBER: builtins.int
    @property
    def note(self) -> global___RichTextNote:
        """笔记"""
    def __init__(
        self,
        *,
        note: global___RichTextNote | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item", "note", b"note"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "note", b"note"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["note"] | None: ...

global___RichText = RichText

@typing_extensions.final
class RichTextNote(google.protobuf.message.Message):
    """笔记"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUMMARY_FIELD_NUMBER: builtins.int
    IMAGES_FIELD_NUMBER: builtins.int
    CLICK_URL_FIELD_NUMBER: builtins.int
    LAST_MTIME_TEXT_FIELD_NUMBER: builtins.int
    summary: builtins.str
    """预览文本"""
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """笔记预览图片url列表"""
    click_url: builtins.str
    """笔记页面url"""
    last_mtime_text: builtins.str
    """发布日期 YYYY-mm-dd"""
    def __init__(
        self,
        *,
        summary: builtins.str = ...,
        images: collections.abc.Iterable[builtins.str] | None = ...,
        click_url: builtins.str = ...,
        last_mtime_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["click_url", b"click_url", "images", b"images", "last_mtime_text", b"last_mtime_text", "summary", b"summary"]) -> None: ...

global___RichTextNote = RichTextNote

@typing_extensions.final
class SearchItem(google.protobuf.message.Message):
    """评论搜索插入项目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    GOODS_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    ARTICLE_FIELD_NUMBER: builtins.int
    url: builtins.str
    """"""
    @property
    def goods(self) -> global___GoodsSearchItem:
        """商品"""
    @property
    def video(self) -> global___VideoSearchItem:
        """视频"""
    @property
    def article(self) -> global___ArticleSearchItem:
        """专栏"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        goods: global___GoodsSearchItem | None = ...,
        video: global___VideoSearchItem | None = ...,
        article: global___ArticleSearchItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["article", b"article", "goods", b"goods", "item", b"item", "video", b"video"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["article", b"article", "goods", b"goods", "item", b"item", "url", b"url", "video", b"video"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["goods", "video", "article"] | None: ...

global___SearchItem = SearchItem

@typing_extensions.final
class SearchItemCursorReply(google.protobuf.message.Message):
    """评论搜索插入项目响应游标"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HAS_NEXT_FIELD_NUMBER: builtins.int
    NEXT_FIELD_NUMBER: builtins.int
    has_next: builtins.bool
    """是否有下一页"""
    next: builtins.int
    """下页"""
    def __init__(
        self,
        *,
        has_next: builtins.bool = ...,
        next: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_next", b"has_next", "next", b"next"]) -> None: ...

global___SearchItemCursorReply = SearchItemCursorReply

@typing_extensions.final
class SearchItemCursorReq(google.protobuf.message.Message):
    """评论搜索插入项目请求游标"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEXT_FIELD_NUMBER: builtins.int
    ITEM_TYPE_FIELD_NUMBER: builtins.int
    next: builtins.int
    """下一页"""
    item_type: global___SearchItemType.ValueType
    """tab类型"""
    def __init__(
        self,
        *,
        next: builtins.int = ...,
        item_type: global___SearchItemType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item_type", b"item_type", "next", b"next"]) -> None: ...

global___SearchItemCursorReq = SearchItemCursorReq

@typing_extensions.final
class SearchItemPreHookReply(google.protobuf.message.Message):
    """评论搜索item前置发布-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACEHOLDER_TEXT_FIELD_NUMBER: builtins.int
    BACKGROUND_TEXT_FIELD_NUMBER: builtins.int
    ORDERED_TYPE_FIELD_NUMBER: builtins.int
    placeholder_text: builtins.str
    """输入框的文案"""
    background_text: builtins.str
    """背景空白的时候的文案"""
    @property
    def ordered_type(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___SearchItemType.ValueType]:
        """有权限的tab栏的顺序"""
    def __init__(
        self,
        *,
        placeholder_text: builtins.str = ...,
        background_text: builtins.str = ...,
        ordered_type: collections.abc.Iterable[global___SearchItemType.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_text", b"background_text", "ordered_type", b"ordered_type", "placeholder_text", b"placeholder_text"]) -> None: ...

global___SearchItemPreHookReply = SearchItemPreHookReply

@typing_extensions.final
class SearchItemPreHookReq(google.protobuf.message.Message):
    """评论搜索item前置发布-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """目标评论区id"""
    type: builtins.int
    """目标评论区业务type"""
    def __init__(
        self,
        *,
        oid: builtins.int = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid", b"oid", "type", b"type"]) -> None: ...

global___SearchItemPreHookReq = SearchItemPreHookReq

@typing_extensions.final
class SearchItemReply(google.protobuf.message.Message):
    """评论搜索插入项目-回复"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURSOR_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___SearchItemCursorReply:
        """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SearchItem]:
        """搜索的结果"""
    @property
    def extra(self) -> global___SearchItemReplyExtraInfo:
        """附加信息"""
    def __init__(
        self,
        *,
        cursor: global___SearchItemCursorReply | None = ...,
        items: collections.abc.Iterable[global___SearchItem] | None = ...,
        extra: global___SearchItemReplyExtraInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor", b"cursor", "extra", b"extra"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor", b"cursor", "extra", b"extra", "items", b"items"]) -> None: ...

global___SearchItemReply = SearchItemReply

@typing_extensions.final
class SearchItemReplyExtraInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    """"""
    def __init__(
        self,
        *,
        event_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_id", b"event_id"]) -> None: ...

global___SearchItemReplyExtraInfo = SearchItemReplyExtraInfo

@typing_extensions.final
class SearchItemReq(google.protobuf.message.Message):
    """评论搜索插入项目-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURSOR_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___SearchItemCursorReq:
        """页面游标"""
    oid: builtins.int
    """目标评论区id"""
    type: builtins.int
    """目标评论区业务type"""
    keyword: builtins.str
    """搜索关键词"""
    def __init__(
        self,
        *,
        cursor: global___SearchItemCursorReq | None = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        keyword: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor", b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor", b"cursor", "keyword", b"keyword", "oid", b"oid", "type", b"type"]) -> None: ...

global___SearchItemReq = SearchItemReq

@typing_extensions.final
class ShareRepliesInfoReq(google.protobuf.message.Message):
    """评论分享材料-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RPIDS_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def rpids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """评论rpid列表"""
    oid: builtins.int
    """目标评论区id"""
    type: builtins.int
    """目标评论区业务type"""
    def __init__(
        self,
        *,
        rpids: collections.abc.Iterable[builtins.int] | None = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid", b"oid", "rpids", b"rpids", "type", b"type"]) -> None: ...

global___ShareRepliesInfoReq = ShareRepliesInfoReq

@typing_extensions.final
class ShareRepliesInfoResp(google.protobuf.message.Message):
    """评论分享材料-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ShareExtra(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IS_PGC_FIELD_NUMBER: builtins.int
        is_pgc: builtins.bool
        """"""
        def __init__(
            self,
            *,
            is_pgc: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["is_pgc", b"is_pgc"]) -> None: ...

    INFOS_FIELD_NUMBER: builtins.int
    FROM_TITLE_FIELD_NUMBER: builtins.int
    FROM_UP_FIELD_NUMBER: builtins.int
    FROM_PIC_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    SLOGAN_PIC_FIELD_NUMBER: builtins.int
    SLOGAN_TEXT_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    @property
    def infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShareReplyInfo]:
        """评论分享条目列表"""
    from_title: builtins.str
    """源内容标题"""
    from_up: builtins.str
    """源内容UP主"""
    from_pic: builtins.str
    """源内容封面url"""
    url: builtins.str
    """源内容页面url"""
    slogan_pic: builtins.str
    """logo url"""
    slogan_text: builtins.str
    """标语"""
    @property
    def topic(self) -> global___ShareReplyTopic:
        """"""
    @property
    def extra(self) -> global___ShareRepliesInfoResp.ShareExtra:
        """"""
    def __init__(
        self,
        *,
        infos: collections.abc.Iterable[global___ShareReplyInfo] | None = ...,
        from_title: builtins.str = ...,
        from_up: builtins.str = ...,
        from_pic: builtins.str = ...,
        url: builtins.str = ...,
        slogan_pic: builtins.str = ...,
        slogan_text: builtins.str = ...,
        topic: global___ShareReplyTopic | None = ...,
        extra: global___ShareRepliesInfoResp.ShareExtra | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extra", b"extra", "topic", b"topic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["extra", b"extra", "from_pic", b"from_pic", "from_title", b"from_title", "from_up", b"from_up", "infos", b"infos", "slogan_pic", b"slogan_pic", "slogan_text", b"slogan_text", "topic", b"topic", "url", b"url"]) -> None: ...

global___ShareRepliesInfoResp = ShareRepliesInfoResp

@typing_extensions.final
class ShareReplyInfo(google.protobuf.message.Message):
    """评论分享条目信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMBER_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    ACHIEVEMENT_TEXT_FIELD_NUMBER: builtins.int
    LABEL_URL_FIELD_NUMBER: builtins.int
    @property
    def member(self) -> global___Member:
        """用户信息"""
    @property
    def content(self) -> global___Content:
        """评论主体信息"""
    title: builtins.str
    """分享标题(评论发布者昵称)"""
    sub_title: builtins.str
    """分享副标题 "发表了评论" """
    achievement_text: builtins.str
    """荣誉信息文案 "获得了up主点赞" """
    label_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        member: global___Member | None = ...,
        content: global___Content | None = ...,
        title: builtins.str = ...,
        sub_title: builtins.str = ...,
        achievement_text: builtins.str = ...,
        label_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "member", b"member"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["achievement_text", b"achievement_text", "content", b"content", "label_url", b"label_url", "member", b"member", "sub_title", b"sub_title", "title", b"title"]) -> None: ...

global___ShareReplyInfo = ShareReplyInfo

@typing_extensions.final
class ShareReplyTopic(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    ORIGIN_TEXT_FIELD_NUMBER: builtins.int
    @property
    def topic(self) -> global___Topic:
        """"""
    origin_text: builtins.str
    """"""
    def __init__(
        self,
        *,
        topic: global___Topic | None = ...,
        origin_text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic", b"topic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["origin_text", b"origin_text", "topic", b"topic"]) -> None: ...

global___ShareReplyTopic = ShareReplyTopic

@typing_extensions.final
class SubjectControl(google.protobuf.message.Message):
    """评论区控制字段"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class FilterTag(google.protobuf.message.Message):
        """评论区筛选类型"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        EVENT_ID_FIELD_NUMBER: builtins.int
        name: builtins.str
        """类型名"""
        event_id: builtins.str
        """"""
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            event_id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["event_id", b"event_id", "name", b"name"]) -> None: ...

    UP_MID_FIELD_NUMBER: builtins.int
    IS_ASSIST_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    HAS_VOTE_ACCESS_FIELD_NUMBER: builtins.int
    HAS_LOTTERY_ACCESS_FIELD_NUMBER: builtins.int
    HAS_FOLDED_REPLY_FIELD_NUMBER: builtins.int
    BG_TEXT_FIELD_NUMBER: builtins.int
    UP_BLOCKED_FIELD_NUMBER: builtins.int
    HAS_ACTIVITY_ACCESS_FIELD_NUMBER: builtins.int
    SHOW_TITLE_FIELD_NUMBER: builtins.int
    SHOW_UP_ACTION_FIELD_NUMBER: builtins.int
    SWITCHER_TYPE_FIELD_NUMBER: builtins.int
    INPUT_DISABLE_FIELD_NUMBER: builtins.int
    ROOT_TEXT_FIELD_NUMBER: builtins.int
    CHILD_TEXT_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    GIVEUP_TEXT_FIELD_NUMBER: builtins.int
    HAS_NOTE_ACCESS_FIELD_NUMBER: builtins.int
    DISABLE_JUMP_EMOTE_FIELD_NUMBER: builtins.int
    EMPTY_BACKGROUND_TEXT_PLAIN_FIELD_NUMBER: builtins.int
    EMPTY_BACKGROUND_TEXT_HIGHLIGHT_FIELD_NUMBER: builtins.int
    EMPTY_BACKGROUND_URI_FIELD_NUMBER: builtins.int
    SUPPORT_FILTER_TAGS_FIELD_NUMBER: builtins.int
    up_mid: builtins.int
    """UP主mid"""
    is_assist: builtins.bool
    """自己是否为协管"""
    read_only: builtins.bool
    """是否只读"""
    has_vote_access: builtins.bool
    """是否有发起投票权限"""
    has_lottery_access: builtins.bool
    """是否有发起抽奖权限"""
    has_folded_reply: builtins.bool
    """是否有被折叠评论"""
    bg_text: builtins.str
    """空评论区背景文案"""
    up_blocked: builtins.bool
    """是否被UP拉黑"""
    has_activity_access: builtins.bool
    """是否有发起活动权限"""
    show_title: builtins.bool
    """标题展示控制"""
    show_up_action: builtins.bool
    """是否显示UP主操作标志"""
    switcher_type: builtins.int
    """是否显示评论区排序切换按钮"""
    input_disable: builtins.bool
    """是否禁止输入框"""
    root_text: builtins.str
    """根评论输入框背景文案"""
    child_text: builtins.str
    """子评论输入框背景文案"""
    count: builtins.int
    """评论总数"""
    title: builtins.str
    """评论区标题"""
    giveup_text: builtins.str
    """离开态输入框的文案"""
    has_note_access: builtins.bool
    """是否允许笔记"""
    disable_jump_emote: builtins.bool
    """"""
    empty_background_text_plain: builtins.str
    """"""
    empty_background_text_highlight: builtins.str
    """"""
    empty_background_uri: builtins.str
    """"""
    @property
    def support_filter_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubjectControl.FilterTag]:
        """评论区筛选类型列表"""
    def __init__(
        self,
        *,
        up_mid: builtins.int = ...,
        is_assist: builtins.bool = ...,
        read_only: builtins.bool = ...,
        has_vote_access: builtins.bool = ...,
        has_lottery_access: builtins.bool = ...,
        has_folded_reply: builtins.bool = ...,
        bg_text: builtins.str = ...,
        up_blocked: builtins.bool = ...,
        has_activity_access: builtins.bool = ...,
        show_title: builtins.bool = ...,
        show_up_action: builtins.bool = ...,
        switcher_type: builtins.int = ...,
        input_disable: builtins.bool = ...,
        root_text: builtins.str = ...,
        child_text: builtins.str = ...,
        count: builtins.int = ...,
        title: builtins.str = ...,
        giveup_text: builtins.str = ...,
        has_note_access: builtins.bool = ...,
        disable_jump_emote: builtins.bool = ...,
        empty_background_text_plain: builtins.str = ...,
        empty_background_text_highlight: builtins.str = ...,
        empty_background_uri: builtins.str = ...,
        support_filter_tags: collections.abc.Iterable[global___SubjectControl.FilterTag] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_text", b"bg_text", "child_text", b"child_text", "count", b"count", "disable_jump_emote", b"disable_jump_emote", "empty_background_text_highlight", b"empty_background_text_highlight", "empty_background_text_plain", b"empty_background_text_plain", "empty_background_uri", b"empty_background_uri", "giveup_text", b"giveup_text", "has_activity_access", b"has_activity_access", "has_folded_reply", b"has_folded_reply", "has_lottery_access", b"has_lottery_access", "has_note_access", b"has_note_access", "has_vote_access", b"has_vote_access", "input_disable", b"input_disable", "is_assist", b"is_assist", "read_only", b"read_only", "root_text", b"root_text", "show_title", b"show_title", "show_up_action", b"show_up_action", "support_filter_tags", b"support_filter_tags", "switcher_type", b"switcher_type", "title", b"title", "up_blocked", b"up_blocked", "up_mid", b"up_mid"]) -> None: ...

global___SubjectControl = SubjectControl

@typing_extensions.final
class SuggestEmotesReq(google.protobuf.message.Message):
    """评论表情推荐列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """目标评论区id"""
    type: builtins.int
    """目标评论区业务type"""
    def __init__(
        self,
        *,
        oid: builtins.int = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid", b"oid", "type", b"type"]) -> None: ...

global___SuggestEmotesReq = SuggestEmotesReq

@typing_extensions.final
class SuggestEmotesResp(google.protobuf.message.Message):
    """评论表情推荐列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMOTES_FIELD_NUMBER: builtins.int
    @property
    def emotes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Emote]:
        """表情推荐列表"""
    def __init__(
        self,
        *,
        emotes: collections.abc.Iterable[global___Emote] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emotes", b"emotes"]) -> None: ...

global___SuggestEmotesResp = SuggestEmotesResp

@typing_extensions.final
class Topic(google.protobuf.message.Message):
    """话题项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LINK_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    link: builtins.str
    """跳转url"""
    id: builtins.int
    """话题id"""
    def __init__(
        self,
        *,
        link: builtins.str = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "link", b"link"]) -> None: ...

global___Topic = Topic

@typing_extensions.final
class UGCVideoSearchItem(google.protobuf.message.Message):
    """UGC视频项目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    UP_NICKNAME_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    up_nickname: builtins.str
    """UP主昵称"""
    duration: builtins.int
    """时长(单位为秒)"""
    cover: builtins.str
    """封面"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        up_nickname: builtins.str = ...,
        duration: builtins.int = ...,
        cover: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "duration", b"duration", "title", b"title", "up_nickname", b"up_nickname"]) -> None: ...

global___UGCVideoSearchItem = UGCVideoSearchItem

@typing_extensions.final
class UpSelection(google.protobuf.message.Message):
    """精选评论"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PENDING_COUNT_FIELD_NUMBER: builtins.int
    IGNORE_COUNT_FIELD_NUMBER: builtins.int
    pending_count: builtins.int
    """待审评论数"""
    ignore_count: builtins.int
    """忽略评论数"""
    def __init__(
        self,
        *,
        pending_count: builtins.int = ...,
        ignore_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ignore_count", b"ignore_count", "pending_count", b"pending_count"]) -> None: ...

global___UpSelection = UpSelection

@typing_extensions.final
class Url(google.protobuf.message.Message):
    """超链项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Extra(google.protobuf.message.Message):
        """扩展字段"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        GOODS_ITEM_ID_FIELD_NUMBER: builtins.int
        GOODS_PREFETCHED_CACHE_FIELD_NUMBER: builtins.int
        GOODS_SHOW_TYPE_FIELD_NUMBER: builtins.int
        IS_WORD_SEARCH_FIELD_NUMBER: builtins.int
        GOODS_CM_CONTROL_FIELD_NUMBER: builtins.int
        goods_item_id: builtins.int
        """"""
        goods_prefetched_cache: builtins.str
        """"""
        goods_show_type: builtins.int
        """"""
        is_word_search: builtins.bool
        """热词搜索"""
        goods_cm_control: builtins.int
        """"""
        def __init__(
            self,
            *,
            goods_item_id: builtins.int = ...,
            goods_prefetched_cache: builtins.str = ...,
            goods_show_type: builtins.int = ...,
            is_word_search: builtins.bool = ...,
            goods_cm_control: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["goods_cm_control", b"goods_cm_control", "goods_item_id", b"goods_item_id", "goods_prefetched_cache", b"goods_prefetched_cache", "goods_show_type", b"goods_show_type", "is_word_search", b"is_word_search"]) -> None: ...

    TITLE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    PREFIX_ICON_FIELD_NUMBER: builtins.int
    APP_URL_SCHEMA_FIELD_NUMBER: builtins.int
    APP_NAME_FIELD_NUMBER: builtins.int
    APP_PACKAGE_NAME_FIELD_NUMBER: builtins.int
    CLICK_REPORT_FIELD_NUMBER: builtins.int
    IS_HALF_SCREEN_FIELD_NUMBER: builtins.int
    EXPOSURE_REPORT_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    UNDERLINE_FIELD_NUMBER: builtins.int
    MATCH_ONCE_FIELD_NUMBER: builtins.int
    PC_URL_FIELD_NUMBER: builtins.int
    ICON_POSITION_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    state: builtins.int
    """"""
    prefix_icon: builtins.str
    """图标url"""
    app_url_schema: builtins.str
    """客户端内跳转uri"""
    app_name: builtins.str
    """"""
    app_package_name: builtins.str
    """"""
    click_report: builtins.str
    """点击上报数据"""
    is_half_screen: builtins.bool
    """是否半屏打开"""
    exposure_report: builtins.str
    """展现上报数据"""
    @property
    def extra(self) -> global___Url.Extra:
        """扩展字段"""
    underline: builtins.bool
    """是否下划线"""
    match_once: builtins.bool
    """"""
    pc_url: builtins.str
    """网页url"""
    icon_position: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        state: builtins.int = ...,
        prefix_icon: builtins.str = ...,
        app_url_schema: builtins.str = ...,
        app_name: builtins.str = ...,
        app_package_name: builtins.str = ...,
        click_report: builtins.str = ...,
        is_half_screen: builtins.bool = ...,
        exposure_report: builtins.str = ...,
        extra: global___Url.Extra | None = ...,
        underline: builtins.bool = ...,
        match_once: builtins.bool = ...,
        pc_url: builtins.str = ...,
        icon_position: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extra", b"extra"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_name", b"app_name", "app_package_name", b"app_package_name", "app_url_schema", b"app_url_schema", "click_report", b"click_report", "exposure_report", b"exposure_report", "extra", b"extra", "icon_position", b"icon_position", "is_half_screen", b"is_half_screen", "match_once", b"match_once", "pc_url", b"pc_url", "prefix_icon", b"prefix_icon", "state", b"state", "title", b"title", "underline", b"underline"]) -> None: ...

global___Url = Url

@typing_extensions.final
class UserCallbackReply(google.protobuf.message.Message):
    """用户回调上报-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UserCallbackReply = UserCallbackReply

@typing_extensions.final
class UserCallbackReq(google.protobuf.message.Message):
    """用户回调上报-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""
    scene: global___UserCallbackScene.ValueType
    """"""
    action: global___UserCallbackAction.ValueType
    """"""
    oid: builtins.int
    """目标评论区id"""
    type: builtins.int
    """目标评论区业务type"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        scene: global___UserCallbackScene.ValueType = ...,
        action: global___UserCallbackAction.ValueType = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "mid", b"mid", "oid", b"oid", "scene", b"scene", "type", b"type"]) -> None: ...

global___UserCallbackReq = UserCallbackReq

@typing_extensions.final
class VideoSearchItem(google.protobuf.message.Message):
    """视频项目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    UGC_FIELD_NUMBER: builtins.int
    PGC_FIELD_NUMBER: builtins.int
    type: global___SearchItemVideoSubType.ValueType
    """"""
    @property
    def ugc(self) -> global___UGCVideoSearchItem:
        """UGC视频"""
    @property
    def pgc(self) -> global___PGCVideoSearchItem:
        """PGC视频"""
    def __init__(
        self,
        *,
        type: global___SearchItemVideoSubType.ValueType = ...,
        ugc: global___UGCVideoSearchItem | None = ...,
        pgc: global___PGCVideoSearchItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pgc", b"pgc", "ugc", b"ugc", "video_item", b"video_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pgc", b"pgc", "type", b"type", "ugc", b"ugc", "video_item", b"video_item"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["video_item", b"video_item"]) -> typing_extensions.Literal["ugc", "pgc"] | None: ...

global___VideoSearchItem = VideoSearchItem

@typing_extensions.final
class Vote(google.protobuf.message.Message):
    """投票信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    id: builtins.int
    """投票id"""
    title: builtins.str
    """投票标题"""
    count: builtins.int
    """参与人数"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        title: builtins.str = ...,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "id", b"id", "title", b"title"]) -> None: ...

global___Vote = Vote



import json

from ..protos.bilibili.app.dynamic.v2.dynamic_pb2 import (
    DynAllReply,
    DynAllReq,
    DynMixUpListViewMoreReply,
    DynMixUpListViewMoreReq,
    DynSpaceReq,
    DynSpaceRsp,
    DynDetailsReq,
    DynDetailsReply,
    DynDetailReq,
    DynDetailReply,
    AdParam,
)
from ..protos.bilibili.app.dynamic.v2.dynamic_pb2_grpc import DynamicStub
from ..utils import grpc_request
from typing import List



@grpc_request
async def grpc_get_user_dynamics(uid: int, offset: str = "", page: int = 1, **kwargs) -> DynSpaceRsp:
    stub = DynamicStub(kwargs.pop("_channel"))
    req = DynSpaceReq(host_uid=uid, history_offset=offset, page=page)
    return await stub.DynSpace(req, **kwargs)


@grpc_request
async def grpc_get_followed_dynamics(**kwargs) -> DynAllReply:
    stub = DynamicStub(kwargs.pop("_channel"))
    req = DynAllReq()
    return await stub.DynAll(req, **kwargs)


@grpc_request
async def grpc_get_followed_dynamic_users(**kwargs) -> DynMixUpListViewMoreReply:
    stub = DynamicStub(kwargs.pop("_channel"))
    req = DynMixUpListViewMoreReq(sort_type=1)
    return await stub.DynMixUpListViewMore(req, **kwargs)


@grpc_request
async def grpc_get_dynamic_details(dynamic_ids: List[int], **kwargs) -> DynDetailsReply:
    stub = DynamicStub(kwargs.pop("_channel"))
    req = DynDetailsReq(dynamic_ids=json.dumps({"dyn_ids": dynamic_ids}))
    return await stub.DynDetails(req, **kwargs)


@grpc_request
async def grpc_get_dynamic_detail(dynamic_id: str, **kwargs) -> DynDetailReply:
    stub = DynamicStub(kwargs.pop("_channel"))
    req = DynDetailReq(dynamic_id=dynamic_id)
    return await stub.DynDetail(req, **kwargs)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Render(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""
    message: builtins.str
    """"""
    ttl: builtins.str
    """"""
    @property
    def data(self) -> google.protobuf.any_pb2.Any:
        """"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        message: builtins.str = ...,
        ttl: builtins.str = ...,
        data: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "data", b"data", "message", b"message", "ttl", b"ttl"]) -> None: ...

global___Render = Render
